@@ -13,7 +13,13 @@
 '''
 
 from __future__ import annotations
-from typing import Literal
+
+import sys
+if sys.version_info >= (3, 8):
+    from typing import Literal
+else:
+    from typing_extensions import Literal
+
 from xml.etree import ElementTree as ET
 
 import string
