@@ -1,7 +1,7 @@
 ''' Schemdraw base Element class '''
 
 from __future__ import annotations
-from typing import Sequence, MutableMapping, Any
+from typing import Sequence, MutableMapping, Any, Union
 from collections import ChainMap
 from dataclasses import dataclass
 import warnings
@@ -62,7 +62,7 @@ class Element:
         self._localshift: XY = Point((0, 0))
         self._userlabels: list[Label] = []
 
-        self.anchors: MutableMapping[str, Any] = {}     # Untransformed anchors
+        self.anchors: MutableMapping[str, Union[Point, tuple[float,float]]] = {}     # Untransformed anchors
         self.absanchors: MutableMapping[str, Any] = {}  # Transformed, absolute anchors
         self.segments: list[SegmentType] = []
         self.transform = Transform(0, [0, 0])
@@ -721,10 +721,10 @@ class Element2Term(Element):
             xy = Point(endpts[0])
 
         if endpts is not None:
-            totlen = math.dist(endpts[0], endpts[1])
+            totlen = util.dist(endpts[0], endpts[1])
         elif to is not None:
             # Move until X or Y position is 'end'. Depends on direction
-            totlen = math.dist(xy, to)
+            totlen = util.dist(xy, to)
         elif tox is not None:
             # Allow either full coordinate (only keeping x), or just an x value
             if isinstance(tox, (int, float)):
@@ -732,7 +732,7 @@ class Element2Term(Element):
             else:
                 x = tox[0]
             endpt = [x, xy[1]]
-            totlen = math.dist(xy, endpt)
+            totlen = util.dist(xy, endpt)
         elif toy is not None:
             # Allow either full coordinate (only keeping y), or just a y value
             if isinstance(toy, (int, float)):
@@ -740,7 +740,7 @@ class Element2Term(Element):
             else:
                 y = toy[1]
             endpt = [xy[0], y]
-            totlen = math.dist(xy, endpt)
+            totlen = util.dist(xy, endpt)
 
         self._localshift = Point((0, 0))
         if self._cparams.get('extend', True):
@@ -765,7 +765,7 @@ class Element2Term(Element):
         self.anchors['center'] = (start+end)/2
 
         if anchor is not None:
-            self._localshift = -self.anchors[anchor]
+            self._localshift = -Point(self.anchors[anchor])
         transform = Transform(theta, xy, self._localshift, zoom)
 
         self.absanchors = {}
